@@ -32,10 +32,11 @@ var dcp_params_default = {
     "cutoff" : null,
     "diff" : null,
     "global" : null,
+    "onepass" : null,
     "profile" : null,
     "format" : "text",
     "debug" : 0,
-    "groupby": null
+    "groupby": null,
 };
 var dynformats = {
     "gmotion" : true,
